@@ -35,6 +35,7 @@ __all__ = (
     "EventResourceTypeDef",
     "EventTimeRangeTypeDef",
     "EventTypeDef",
+    "InsightFeedbackTypeDef",
     "InsightHealthTypeDef",
     "InsightTimeRangeTypeDef",
     "ListInsightsAnyStatusFilterTypeDef",
@@ -70,11 +71,11 @@ __all__ = (
     "DescribeAccountHealthResponseTypeDef",
     "DescribeAccountOverviewResponseTypeDef",
     "DescribeAnomalyResponseTypeDef",
+    "DescribeFeedbackResponseTypeDef",
     "DescribeInsightResponseTypeDef",
     "DescribeResourceCollectionHealthResponseTypeDef",
     "DescribeServiceIntegrationResponseTypeDef",
     "GetResourceCollectionResponseTypeDef",
-    "InsightFeedbackTypeDef",
     "ListAnomaliesForInsightResponseTypeDef",
     "ListEventsFiltersTypeDef",
     "ListEventsResponseTypeDef",
@@ -167,6 +168,21 @@ EventTypeDef = TypedDict(
     total=False,
 )
 
+InsightFeedbackTypeDef = TypedDict(
+    "InsightFeedbackTypeDef",
+    {
+        "Id": str,
+        "Feedback": Literal[
+            "VALID_COLLECTION",
+            "RECOMMENDATION_USEFUL",
+            "ALERT_TOO_SENSITIVE",
+            "DATA_NOISY_ANOMALY",
+            "DATA_INCORRECT",
+        ],
+    },
+    total=False,
+)
+
 InsightHealthTypeDef = TypedDict(
     "InsightHealthTypeDef",
     {
@@ -452,6 +468,10 @@ DescribeAnomalyResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeFeedbackResponseTypeDef = TypedDict(
+    "DescribeFeedbackResponseTypeDef", {"InsightFeedback": "InsightFeedbackTypeDef"}, total=False
+)
+
 DescribeInsightResponseTypeDef = TypedDict(
     "DescribeInsightResponseTypeDef",
     {"ProactiveInsight": "ProactiveInsightTypeDef", "ReactiveInsight": "ReactiveInsightTypeDef"},
@@ -486,21 +506,6 @@ GetResourceCollectionResponseTypeDef = TypedDict(
     total=False,
 )
 
-InsightFeedbackTypeDef = TypedDict(
-    "InsightFeedbackTypeDef",
-    {
-        "Id": str,
-        "Feedback": Literal[
-            "VALID_COLLECTION",
-            "RECOMMENDATION_USEFUL",
-            "ALERT_TOO_SENSITIVE",
-            "DATA_NOISY_ANOMALY",
-            "DATA_INCORRECT",
-        ],
-    },
-    total=False,
-)
-
 ListAnomaliesForInsightResponseTypeDef = TypedDict(
     "ListAnomaliesForInsightResponseTypeDef",
     {
